==> fmsystem-0.9.17.001.tar.gz: fmsystem/phpgwapi/inc/class.contact_categories.inc.php <==
<?php
	/**
	* Query statements for "categories" table
	* @author Edgar Antonio Luna <eald@co.com.mx>
	* @copyright Copyright (C) 2003,2004 Free Software Foundation, Inc. http://www.fsf.org/
	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
	* @package phpgwapi
	* @subpackage contacts
	* @version $Id: class.contact_categories.inc.php,v 1.2 2007/02/06 12:42:17 sigurdne Exp $
	*/

	/**
	* Use SQL criteria
	*/
	include_once(PHPGW_API_INC . '/class.sql_criteria.inc.php');
	/**
	* Use SQL entity
	*/
	include_once(PHPGW_API_INC . '/class.sql_entity.inc.php');

	/**
	* Query statements for "categories" table
	*
	* @package phpgwapi
	* @subpackage contacts
	*/
	class contact_categories extends sql_entity
	{
		var $map = array('key_cat_id'		=> array('select'	=> '',
								 'criteria' 	=> '',
								 'insert'   	=> '',
								 'update'	=> '',
								 'delete'	=> '',
								 'sort'		=> '',
								 'field'	=> 'cat_id',
								 'type'		=> 'integer'),
				 'parent_id'		=> array('select'	=> '',
								 'criteria' 	=> '',
								 'insert'   	=> '',
								 'update'	=> '',
								 'delete'	=> '',
								 'sort'		=> '',
								 'field'	=> 'cat_id',
								 'type'		=> 'integer'));
		
		
		function contact_categories ($ali = '', $field = '', $criteria = 	'')
		{
			$this->_constructor('phpgw_categories', 'contact_categories');
			if($field)
			{
				$this->add_select($field);
			}
			if($criteria)
			{
				$this->add_criteria($criteria);
			}
			//$this->set_elinks('key_cat_id', 'contact_central','cat_id');
		}		

		function select_parent_id($element)
		{
			$this->set_alias('categorie_parent');
			$this->_add_field(array('field' => 'parent_id', 'real_field' => 'cat_id'));
			$this->set_elinks('key_cat_id', 'phpgwapi.contact_categories','parent_id');
		}
	}
?>

==> fmsystem-1.0.002.tar.gz: fmsystem/phpgwapi/inc/class.contact_categories.inc.php <==
<?php
	/**
	* Query statements for "categories" table
	* @author Edgar Antonio Luna <eald@co.com.mx>
	* @copyright Copyright (C) 2003,2004 Free Software Foundation, Inc. http://www.fsf.org/
	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
	* @package phpgwapi
	* @subpackage contacts
	* @version $Id: class.contact_categories.inc.php 1040 2008-05-26 10:27:54Z dave $
	*/

	/**
	* Use SQL criteria
	*/
	phpgw::import_class('phpgwapi.sql_criteria');

	/**
	* Use SQL entity
	*/
	phpgw::import_class('phpgwapi.sql_entity');

	/**
	* Query statements for "categories" table
	*
	* @package phpgwapi
	* @subpackage contacts
	*/
	class contact_categories extends phpgwapi_sql_entity
	{
		var $map = array('key_cat_id'		=> array('select'	=> '',
								 'criteria' 	=> '',
								 'insert'   	=> '',
								 'update'	=> '',
								 'delete'	=> '',
								 'sort'		=> '',
								 'field'	=> 'cat_id',
								 'type'		=> 'integer'),
				 'parent_id'		=> array('select'	=> '',
								 'criteria' 	=> '',
								 'insert'   	=> '',
								 'update'	=> '',
								 'delete'	=> '',
								 'sort'		=> '',
								 'field'	=> 'cat_id',
								 'type'		=> 'integer'));
		
		
		function contact_categories ($ali = '', $field = '', $criteria = 	'')
		{
			$this->_constructor('phpgw_categories', 'contact_categories');
			if($field)
			{
				$this->add_select($field);
			}
			if($criteria)
			{
				$this->add_criteria($criteria);
			}
			//$this->set_elinks('key_cat_id', 'contact_central','cat_id');
		}		

		function select_parent_id($element)
		{
			$this->set_alias('categorie_parent');
			$this->_add_field(array('field' => 'parent_id', 'real_field' => 'cat_id'));
			$this->set_elinks('key_cat_id', 'phpgwapi.contact_categories','parent_id');
		}
	}
